@@ -1,7 +1,7 @@
 #
-# $Id: RequestArgs.pl,v 33.3 2011/01/03 15:04:47 anbrown Exp $
+# $Id: RequestArgs.pl,v 33.5 2012/09/26 16:10:15 jettisu Exp $
 #
-# (c) 1999-2011 Morgan Stanley & Co. Incorporated
+# (c) 1999-2012 Morgan Stanley & Co. Incorporated
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -48,6 +48,16 @@ package MQSeries::Command::MQSC;
     QName                       => 1,
    },
 
+   SetChlAuthRec =>
+   {
+    ChlAuth			=> 1,
+   },
+
+   InquireChlAuthRecs =>
+   {
+    ChlAuth			=> 1,
+   },
+
   );
 
 1;
