@@ -1,7 +1,7 @@
 #
-# $Id: Responses.pl,v 33.3 2011/01/03 15:04:48 anbrown Exp $
+# $Id: Responses.pl,v 33.6 2012/09/26 16:13:39 jettisu Exp $
 #
-# (c) 1999-2011 Morgan Stanley & Co. Incorporated
+# (c) 1999-2012 Morgan Stanley & Co. Incorporated
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -79,6 +79,9 @@ package MQSeries::Command::MQSC;
    InquireTrace			=> $ResponseParameters{Trace},
 
    InquireClusterQueueManager	=> $ResponseParameters{Cluster},
+
+   InquireChlAuthRecs		=> $ResponseParameters{ChlAuthRec},
+   SetChlAuthRec		=> $ResponseParameters{ChlAuthRec},
   );
 
 #
